@@ -64,8 +64,6 @@ class DeviceControlsWidget(QtGui.QGroupBox):
             self._mode.removeItem(0)
         for m in dut_prop.RFE_MODES:
             self._mode.addItem(m)
-        self._mode.addItem('Sweep ZIF')
-        self._mode.addItem('Sweep ZIF left band')
         self._mode.addItem('Sweep SH')
 
     def _antenna_control(self):
